import javax.swing.JOptionPane;
import javax.swing.Timer;
import javax.swing.JFrame;
import java.util.Observer;
import java.util.Observable;

/**
 * In this version, Testbed creates a (do-nothing) JFrame in addition to the
 * Counters.  For thread-safety, we set up the JFrame in the event-handling thread
 * using invokeLater and an anonymous Runnable object.
 * @since version 3, Feb 2
 * @version 7, Feb 2
 */
public class Testbed
{
    public static void test ()
    {
        Counter a = new Counter ();
        Counter b = new Counter ();
        a.addObserver (new Observer () {
            public void update (Observable o, Object newValue) {
                System.out.println ("Counter a value: " + newValue);
            } // end update method
        } // end anonymous inner class
        ); // end addObserver
        b.addObserver (new Observer () {
            public void update (Observable o, Object newValue) {
                System.out.println ("Counter b value: " + newValue);
            } // end update method
        } // end anonymous inner class
        ); // end addObserver
            
        javax.swing.SwingUtilities.invokeLater (new Runnable() {
            public void run () {
                JFrame.setDefaultLookAndFeelDecorated(true);
                JFrame theFrame = new JFrame ("My counter demonstration program");
                theFrame.setSize (300, 200);
                theFrame.setVisible (true);
            } // end run method
        } // end anonymous inner class
        ); // end invokeLater

        Timer timerA = new Timer(1000, a.getIncrementer());
        Timer timerB = new Timer(2000, b.getIncrementer());
        timerB.start();
        timerA.start();
        JOptionPane.showMessageDialog(null, "Quit?");
        System.exit(0);
    } // end test method
} // end Testbed class
