import javax.swing.JOptionPane;
import javax.swing.Timer;
import java.util.Observer;
import java.util.Observable;


/**
 * Create two Counters with associated Timers, and a "quit" dialog box so we can
 * end the program a little more neatly.
 * In this version, we move all the graphical stuff out of the main program
 * and into CounterComponent, which makes it a no-brainer to create multiple
 * graphical views of various counters.
 * @since version 3, Feb 2
 * @version 9, Feb 2
 */
public class Testbed
{    
    public static void test ()
    {
        final Counter a = new Counter ();
        final Counter b = new Counter ();
        a.addObserver (new Observer () {
            public void update (Observable o, Object newValue) {
                System.out.println ("Counter a value: " + newValue);
            }
        });
        b.addObserver (new Observer () {
            public void update (Observable o, Object newValue) {
                System.out.println ("Counter b value: " + newValue);
            }
        });
        new CounterComponent (a, "Counter a");
        // creates a frame and attaches the CounterComponent as an Observer of a
        new CounterComponent (b, "Counter b");
        new CounterComponent (a, "Counter a again");

        Timer timerA = new Timer(1000, a.getIncrementer());
        Timer timerB = new Timer(2000, b.getIncrementer());
        timerB.start();
        timerA.start();
        JOptionPane.showMessageDialog(null, "Quit?");
        System.exit(0);
    }
}
